import { spellCheckDocument } from 'cspell-lib';
export async function checkSpelling(text) {
    if (!text) {
        return [];
    }
    const results = await spellCheckDocument({
        text,
        uri: '',
        languageId: 'plaintext',
        locale: 'en',
    }, {
        generateSuggestions: false,
    }, {});
    return results.issues;
}
export function makeMessage(property, issues) {
    if (issues.length) {
        const misspelledWords = issues.map((issue) => issue.text);
        return `Spelling error found in ${property}: ${misspelledWords.join(', ')}`;
    }
}
export function makeRule(property) {
    return async (parsed) => {
        const issues = await checkSpelling(parsed[property]);
        return [!issues.length, makeMessage(property, issues)];
    };
}
//# sourceMappingURL=utils.js.map